/*****
 ForgetMeNot, Window
*****/

#include <ESP8266WiFi.h>
#include <PubSubClient.h>

// Change the credentials below, so your ESP8266 connects to your network. USE A HOTSPOT! Proper WiFi does not work for some reason
const char* ssid = "<WIFI_SSID>";
const char* password = "<WIFI_PASSWORD>";

// Run Mosquitto, do "ifconfig" and get the IP address of your laptop on the HOTSPOT's interface, and add it here
const char* mqtt_server = "<YOUR_LOCAL_MQTT_BROKER_IP>";
 
// Initializes the espClient
WiFiClient espClient;
PubSubClient client(espClient);

// Set pins
#define INPUT_PIN D1

int currentWindowStatus = 0;

// This function connects your ESP8266 to your router
void setup_wifi() {
  delay(10);
  // We start by connecting to a WiFi network
  Serial.begin(9600);
  Serial.println();
  Serial.print("Connecting to ");
  Serial.println(ssid);
  WiFi.begin(ssid, password);
  while (WiFi.status() != WL_CONNECTED) {
    delay(500);
    Serial.print(".");
  }
  Serial.println("");
  Serial.print("WiFi connected - ESP IP address: ");
  Serial.println(WiFi.localIP());
}

// This function reconnects your ESP8266 to your MQTT broker
void reconnect() {
  // Loop until we're reconnected
  while (!client.connected()) {
    Serial.print("Attempting MQTT connection...");
    if (client.connect("ESP8266Window")) {
      Serial.println("connected");  
    } else {
      Serial.print("failed, rc=");
      Serial.print(client.state());
      Serial.println(" try again in 5 seconds");
      // Wait 5 seconds before retrying
      delay(5000);
    }
  }
}

// Starts the serial communication at a baud rate of 9600, sets your mqtt broker
void setup() {
  pinMode(INPUT_PIN, INPUT_PULLUP);
  Serial.begin(9600);
  setup_wifi();
  client.setServer(mqtt_server, 1883);
}

// This part ensures that you ESP is connected to your broker
void loop() {
  if (!client.connected()) {
    reconnect();
  }
  int windowStatus = digitalRead(INPUT_PIN);
  char* msg;
  if(currentWindowStatus != windowStatus){
    currentWindowStatus = windowStatus;
    if(windowStatus == 0){
      msg = "closed";
    }else{
      msg = "open";
    }
    client.publish("house/window",msg); 
  }
  Serial.println(windowStatus);
} 
